@@ -29,7 +29,7 @@ class Execution:
         self._syncmode_music = SyncMode(self._raw['music'])
 
     async def _put(self, data):
-        await self._request('put', '/execution', json=data)
+        await self._request('put', '/execution', data=data)
 
     @property
     def sync_active(self):
@@ -104,12 +104,12 @@ class Execution:
 
     async def cycle_sync_mode(self, next=True):
         """Cycle through sync modes."""
-        data = {'cycleSyncMode': 'next' if next else 'prev'}
+        data = {'cycleSyncMode': 'next' if next else 'previous'}
         await self._put(data)
 
     async def cycle_hdmi_source(self, next=True):
         """Cycle through HDMI sources."""
-        data = {'cycleHdmiSource': 'next' if next else 'prev'}
+        data = {'cycleHdmiSource': 'next' if next else 'previous'}
         await self._put(data)
 
     async def increment_brightness(self, step):
@@ -119,7 +119,7 @@ class Execution:
 
     async def cycle_intensity(self, next=True):
         """Cycle through intensities of current mode if syncing."""
-        data = {'cycleIntensity': 'next' if next else 'prev'}
+        data = {'cycleIntensity': 'next' if next else 'previous'}
         await self._put(data)
 
     async def set_intensity(self, intensity):
@@ -127,19 +127,25 @@ class Execution:
         data = {'intensity': intensity}
         await self._put(data)
 
-    async def set_state(self, sync_active=None, hdmi_active=None, mode=None, hdmi_source=None, brightness=None, video=None, game=None, music=None, intensity=None):
+    async def set_state(self, sync_active=None, sync_toggle=None, hdmi_active=None, hdmi_active_toggle=None, mode=None, mode_cycle=None, hdmi_source=None, hdmi_source_cycle=None, brightness=None, brightness_step=None, video=None, game=None, music=None, intensity=None, intensity_cycle=None):
         """Change execution state of huesyncbox."""
         data = {
             key: value for key, value in {
                 'syncActive': sync_active,
+                'toggleSyncActive': True if sync_toggle is True else None,
                 'hdmiActive': hdmi_active,
+                'toggleHdmiActive': True if hdmi_active_toggle is True else None,
                 'mode': mode,
+                'cycleSyncMode': mode_cycle,
                 'hdmiSource': hdmi_source,
+                'cycleHdmiSource': hdmi_source_cycle,
                 'brightness': brightness,
+                'incrementBrightness': brightness_step,
+                'intensity': intensity,
+                'cycleIntensity': intensity_cycle,
                 'video': video,
                 'game': game,
                 'music': music,
-                'intensity': intensity,
             }.items() if value is not None
         }
         await self._put(data)
